/*
* file CcFileAreaLockedCallback.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcFileAreaLockedCallback
*
* (C) Copyright IBM Corporation 2007, 2011.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import java.util.Date;

import javax.wvcm.WvcmException;

/**
 * Interface to permit applications to deal gracefully with 
 * FileAreaLockedExceptions.  Applies to web views only - not dynamic views.
 */
public interface CcFileAreaLockedCallback {
    
    /**
     * Information about a file area lock.
     */
    public interface CcFileAreaLockInfo {
        
        /** 
         * Get the date object was locked.
         * @return Date the lock was applied. 
         */
        public Date getCreationDate();
        
        /** 
         * Get the hostname of the user who set the lock.
         * @return String the hostname
         */
        public String getHostName();
        
        /**
         * Get the locked view.
         * @return the locked view
         */
        public CcView getView();
    }
    
    /**
     * Notify the client about the occurrence of a 
     * CopyAreaLockedException. The client may decide
     * to break the lock. If so it should break the lock
     * using the {@link CcView#breakFileAreaLock} method.
     * 
     * @param lockInfo      Details about the lock.
     * @return              True if the lock was broken,
     *                      otherwise false.
     */
    public boolean handleLockedFileArea(CcFileAreaLockInfo lockInfo)
        throws WvcmException;
}
